<?php
namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Medicine;
use Illuminate\Http\Request;

class MedicineController extends Controller
{
    public function category()
    {
        $category = Category::all();
        return (view('medicine.category', compact('category')));
    }
    public function categoryCreate()
    {
        return (view('medicine.categoryCreate'));
    }
    public function categoryStore(Request $request)
    {
        $validated = $request->validate([
            'category_name' => 'required|max:255',
            'unit'          => 'required',
        ]);

        $data = $request->except('_token');
        Category::create($data);

        return redirect('category')->with('success', "Category added successfully");
    }

    public function categoryEdit($id)
    {
        $category = Category::where('id', $id)->first();
        return (view('medicine.categoryEdit', compact('category')));
    }
    public function categoryUpdate(Request $request, $id)
    {
        $validated = $request->validate([
            'category_name' => 'required|max:255',
            'unit'          => 'required',
        ]);

        $data = $request->except('_token');
        Category::where('id', $id)->update($data);

        return redirect('category')->with('success', "Category updated successfully");
    }

    public function categoryDestroy($id)
    {
        Category::where('id', $id)->delete();
        return redirect('category')->with('success', "Category deleted successfully");

    }

    public function medicine()
    {
        $medicine = Medicine::with('category')->get();
        return (view('medicine.medicine', compact('medicine')));
    }
    public function medicineCreate()
    {
        $category = Category::all();
        return (view('medicine.medicineCreate', compact('category')));
    }
    public function medicineImport()
    {
        $category = Category::all();
        return (view('medicine.medicineImport', compact('category')));
    }
    public function medicineStore(Request $request)
    {
        $validated = $request->validate([
            'category_id' => 'required|max:255',
            'name'        => 'required',
            'price'       => 'required',
            'quantity'    => 'required',
        ], ['category_id' => 'The category field is required.']);

        $data          = $request->except('_token');
        $data['stock'] = $request->quantity * $request->stock;
        Medicine::create($data);

        return redirect('medicine')->with('success', "Medicine added successfully");
    }

    public function medicineImportStore(Request $request)
    {
        $validated = $request->validate([
            'file' => 'required|mimes:csv|max:2048']);

        if ($request->hasFile('file')) {
            $file = $request->file('file');
            $path = $file->getRealPath();

            $csvData = file($path, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);

            if (! empty($csvData)) {
                $headers = str_getcsv(array_shift($csvData));
                $headers[0] = preg_replace('/^\xEF\xBB\xBF/', '', $headers[0]);
                foreach ($csvData as $row) {
                    $rowData = str_getcsv($row);

                    // Ensure row data matches header count
                    if (count($rowData) == count($headers)) {
                        $data = array_combine($headers, $rowData);
                        $data['stock'] = $data['quantity'] * $data['stock'];
                        Medicine::create($data);
                    }
                }
                return back()->with('success', 'CSV imported successfully!');
            }
        }
        // $data          = $request->except('_token');
        // $data['stock'] = $request->quantity * $request->stock;
        // Medicine::create($data);

        return redirect('medicine')->with('success', "Medicine added successfully");
    }

    public function medicineEdit($id)
    {
        $category = Category::all();
        $medicine = Medicine::where('id', $id)->first();
        return (view('medicine.medicineEdit', compact('category', 'medicine')));
    }
    public function medicineUpdate(Request $request, $id)
    {
        $validated = $request->validate([
            'category_id' => 'required|max:255',
            'name'        => 'required',
            'price'       => 'required',
            'quantity'    => 'required',
        ], ['category_id' => 'The category field is required.']);

        $data          = $request->except('_token');
        $data['stock'] = $request->quantity * $request->stock;
        Medicine::where('id', $id)->update($data);

        return redirect('medicine')->with('success', "Medicine updated successfully");
    }

    public function medicineDestroy($id)
    {
        Medicine::where('id', $id)->delete();
        return redirect('medicine')->with('success', "Medicine deleted successfully");

    }

    public function getMedicineByCategory(Request $request)
    {
        $medicine = Medicine::where('category_id', $request->category_id)->get();
        return response()->json($medicine);
    }

    public function medicineStock(Request $request)
    {
        $result = Medicine::where('id', $request->medicine_id)->select('stock', 'quantity', 'price')->first();
        return response()->json($result);

    }
}
