<?php
namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Expense;
use App\Models\Medicine;
use App\Models\Purchase;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class PurchaseController extends Controller
{
    public function purchase()
    {
        $category  = Category::all();
        $medicines = Medicine::all();
        return (view('purchase.index', compact('category', 'medicines')));
    }

    public function addExpense()
    {

        return (view('purchase.addExpense'));
    }

    public function store(Request $request)
    {$validated = $request->validate([
        'category_id' => 'required',
        'medicine_id' => 'required',
        'date'        => 'required',
        'quantity'    => 'required',
    ]);

        $data         = $request->except('_token');
        $data['date'] = date('Y-m-d', strtotime($request->date));
        Purchase::create($data);
        $medicineDetails = Medicine::where('id', $request->medicine_id)->select('quantity', 'price')->first();
        $purchaseAmount  = round($medicineDetails->price - (($medicineDetails->price * 22) / 100));
        $totalAmount     = $purchaseAmount * $request->quantity;
        $stock           = $request->quantity * $medicineDetails->quantity;
        Medicine::where('id', $request->medicine_id)->increment('stock', $stock);
        $expense = ['date' => date('Y-m-d', strtotime($request->date)),
            'amount'           => $totalAmount,
            'type'             => "Medicine Purchase",
            'description'      => "Purchase of medicine",
        ];
        Expense::create($expense);

        return redirect('purchase')->with('success', "Purchase added successfully");}

    public function expenseStore(Request $request)
    {$validated = $request->validate([
        'amount' => 'required',
        'type'   => 'required',
        'date'   => 'required',
    ]);

        $data         = $request->except('_token');
        $data['date'] = date('Y-m-d', strtotime($request->date));

        Expense::create($data);

        return redirect('add-expense')->with('success', "Purchase added successfully");}

    public function purchaseReport()
    {
        $result    = false;
        $from_date = date('d-m-Y');
        $to_date   = date('d-m-Y');
        return (view('purchase.report', compact('result', 'from_date', 'to_date')));

    }
    public function purchaseReportSearch(Request $request)
    {
        $validated = $request->validate([
            'from_date' => 'required',
            'to_date'   => 'required',
        ]);
        $from_date = $request->from_date;
        $to_date   = $request->to_date;
        $result    = DB::table('purchases')->select('*', 'purchases.quantity as qty')->join('medicines', 'medicines.id', '=', 'purchases.medicine_id')->join('categories', 'categories.id', '=', 'medicines.category_id')->whereBetween('date', [date('Y-m-d', strtotime($request->from_date)), date('Y-m-d', strtotime($request->to_date))])->orderBy('purchases.id', 'desc')->get();
        return (view('purchase.report', compact('result', 'from_date', 'to_date')));

    }
    public function purchaseMedicineReport()
    {
        $result      = false;
        $category    = Category::all();
        $medicines   = Medicine::all();
        $category_id = "";
        $medicine_id = "";
        return (view('purchase.medicineReport', compact('result', 'category', 'medicines', 'category_id', 'medicine_id')));

    }
    public function purchaseMedicineSearch(Request $request)
    {
        $validated = $request->validate([
            'category_id' => 'required',
            'medicine_id' => 'required',
        ]);
        $category    = Category::all();
        $medicines   = Medicine::all();
        $category_id = $request->category_id;
        $medicine_id = $request->medicine_id;
        $to_date     = $request->to_date;
        $result      = DB::table('purchases')->select('*', 'purchases.quantity as qty')
            ->join('medicines', 'medicines.id', '=', 'purchases.medicine_id')
            ->join('categories', 'categories.id', '=', 'medicines.category_id')
            ->where('purchases.medicine_id', $medicine_id)
            ->orderBy('date', 'desc')
            ->get();
        return (view('purchase.medicineReport', compact('result', 'category_id', 'medicine_id', 'category', 'medicines')));

    }
}
